summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/mon-stealth.cc
diff options
context:
space:
mode:
authorAdam Borowski <kilobyte@angband.pl>2011-09-07 11:53:03 +0200
committerAdam Borowski <kilobyte@angband.pl>2011-09-07 11:53:03 +0200
commit9b110db93636bf173f45d0a66c2cd3540c50fe21 (patch)
treebb6c03c4d3394c3a5b26f54c3f21cc8acee2a456 /crawl-ref/source/mon-stealth.cc
parentf2b92c85657b07c36fc955da0f4c4fcda5f1ddeb (diff)
downloadcrawl-ref-9b110db93636bf173f45d0a66c2cd3540c50fe21.tar.gz
crawl-ref-9b110db93636bf173f45d0a66c2cd3540c50fe21.zip
s/antihalo/umbra/g in the code as well, to match the new user-visible name.
Diffstat (limited to 'crawl-ref/source/mon-stealth.cc')
-rw-r--r--crawl-ref/source/mon-stealth.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/crawl-ref/source/mon-stealth.cc b/crawl-ref/source/mon-stealth.cc
index 0c4d6db4e4..bf95203d8a 100644
--- a/crawl-ref/source/mon-stealth.cc
+++ b/crawl-ref/source/mon-stealth.cc
@@ -70,8 +70,8 @@ int monster::stealth() const
if (glows_naturally() || halo_radius2() != -1)
actual_stealth -= 3;
- // Having an antihalo makes you more stealthy, on the other hand.
- if (antihalo_radius2() != -1)
+ // Having an umbra makes you more stealthy, on the other hand.
+ if (umbra_radius2() != -1)
actual_stealth += 3;
// Some specific overrides